================
epicteller-datum
================


.. image:: https://img.shields.io/pypi/v/epicteller-datum.svg
        :target: https://pypi.python.org/pypi/epicteller-datum

.. image:: https://img.shields.io/travis/epicteller/datum.svg
        :target: https://travis-ci.org/epicteller/datum

.. image:: https://coveralls.io/repos/github/epicteller/datum/badge.svg?branch=master
        :target: https://coveralls.io/github/epicteller/datum?branch=master



Dice parser for Epicteller.


* Free software: GNU General Public License v3
